@@ -1,35 +1,36 @@
-/*
-  The contents of this file are subject to the Mozilla Public
-  License Version 1.1 (the "MPL"); you may not use this file
-  except in compliance with the MPL. You may obtain a copy of
-  the MPL at http://www.mozilla.org/MPL/
-
-  Software distributed under the MPL is distributed on an "AS
-  IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
-  implied. See the MPL for the specific language governing
-  rights and limitations under the MPL.
-
-  The Original Code is Enigmail.
-
-  The Initial Developer of this code is Patrick Brunschwig.
-  Portions created by Patrick Brunschwig <patrick.brunschwig@gmx.net>
-  are Copyright (C) 2007 Patrick Brunschwig.
-  All Rights Reserved.
-
-  Contributor(s):
-
-  Alternatively, the contents of this file may be used under the
-  terms of the GNU General Public License (the "GPL"), in which case
-  the provisions of the GPL are applicable instead of
-  those above. If you wish to allow use of your version of this
-  file only under the terms of the GPL and not to allow
-  others to use your version of this file under the MPL, indicate
-  your decision by deleting the provisions above and replace them
-  with the notice and other provisions required by the GPL.
-  If you do not delete the provisions above, a recipient
-  may use your version of this file under either the MPL or the
-  GPL.
-*/
+/* ***** BEGIN LICENSE BLOCK *****
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
+ *
+ * The contents of this file are subject to the Mozilla Public
+ * License Version 1.1 (the "MPL"); you may not use this file
+ * except in compliance with the MPL. You may obtain a copy of
+ * the MPL at http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the MPL is distributed on an "AS
+ * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+ * implied. See the MPL for the specific language governing
+ * rights and limitations under the MPL.
+ *
+ * The Original Code is Enigmail.
+ *
+ * The Initial Developer of the Original Code is Patrick Brunschwig.
+ * Portions created by Patrick Brunschwig <patrick@mozilla-enigmail.org> are
+ * Copyright (C) 2007 Patrick Brunschwig. All Rights Reserved.
+ *
+ * Contributor(s):
+ *
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
+ * ***** END LICENSE BLOCK ***** */
 
 
 EnigInitCommon("enigmailKeyDetailsDlg");
@@ -208,6 +209,10 @@ function viewSignatures() {
 
 }
 
+function keyDetailsAddPhoto() {
+  keyMgrAddPhoto(gUserId, gKeyId);
+}
+
 function signKey() {
   if (EnigSignKey(gUserId, gKeyId, null)) {
     enableRefresh();
